@@ -4,6 +4,7 @@
 from cow.server import Server
 from cow.plugins.motor_plugin import MotorPlugin
 from cow.plugins.redis_plugin import RedisPlugin
+from cow.plugins.es_plugin import ESPlugin
 
 from tests.sandbox.handlers.test import TestHandler
 
@@ -17,7 +18,8 @@ class SandboxServer(Server):
     def get_plugins(self):
         return [
             MotorPlugin,
-            RedisPlugin
+            RedisPlugin,
+            ESPlugin
         ]
 
 if __name__ == '__main__':
